Page parts
----------

.. tabularcolumns:: |p{3.7cm}|p{6.1cm}|p{1.5cm}|p{1.5cm}|p{1.5cm}|
.. list-table::
   :header-rows: 1

   * - Part name
     - Description
     - l18n
     - Required
     - Unique

   * - Menu
     - It is important to choose simple short name. It is used for menu.
     - yes
     - yes
     - no
     
   * - Name
     - It is the title of the article. If it is not set "Menu" is used instead.
     - yes
     - no
     - no 

   * - Central Column
     - Central column of the article
     - yes
     - yes
     - no

   * - Right Column: Text
     - Right Column of the article. Central column of the article.
     - yes
     - no
     - no   

   * - Right Column: Multimedia
     - Photo or video that are available in the Right Column
     - no
     - no
     - no     

   * - Bottom columns
     - Columns in the bottom side of the article. There are only 3 or less  bottom columns.
     - yes
     - no
     - no     
